@@ -1,11 +1,11 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1396 2015-09-14 21:16:36Z willem $
+# $Id: SEC.pm 1398 2015-09-15 18:45:49Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '1.01_02';
-$SVNVERSION = (qw$LastChangedRevision: 1396 $)[1];
+$VERSION    = '1.01_03';
+$SVNVERSION = (qw$LastChangedRevision: 1398 $)[1];
 
 
 =head1 NAME
@@ -44,11 +44,11 @@ use integer;
 use warnings;
 use Carp;
 
-eval { require Net::DNS::RR::CDS };
-eval { require Net::DNS::RR::DLV };
-eval { require Net::DNS::RR::DS };
-eval { require Net::DNS::RR::RRSIG };
-eval { require Net::DNS::RR::SIG };
+use Net::DNS::RR::CDS;
+use Net::DNS::RR::DLV;
+use Net::DNS::RR::DS;
+use Net::DNS::RR::RRSIG;
+use Net::DNS::RR::SIG;
 
 
 =head1 UTILITY FUNCTIONS
@@ -97,6 +97,7 @@ sub key_difference {
 	my $r = shift || [];		## 0.17 interface
 
 	eval {
+		local $SIG{__DIE__};
 		my ($x) = grep !$_->isa('Net::DNS::RR::DNSKEY'), @$a, @$b;
 		die sprintf 'unexpected %s object in key list', ref($x) if $x;
 
